@@ -73,3 +73,15 @@ push(@t, sprintf('%.02f', time - $start));
 $f->cls('ON');
 
 print STDERR "CIRCLE STRING: $t[0]\n  CIRCLE FILE: $t[1]\n   BOX STRING: $t[2]\n     BOX FILE: $t[3]\n  LINE STRING: $t[4]\n    LINE FILE: $t[5]\n\n";
+
+my $file_average   = ($t[1] + $t[3] + $t[5]) / 3;
+my $string_average = ($t[0] + $t[2] + $t[4]) / 3;
+
+print STDERR "Memory Mapped String Mode Average: $string_average\n";
+print STDERR "File Handle Mode Average: $file_average\n\n";
+
+if ($file_average > $string_average) {
+    print STDERR "It is recommended you use the default Mmap string mode for your framebuffer device.\n";
+} else {
+    print STDERR "It is recommend you use the File Handle mode for your framebuffer device.\n";
+}
