@@ -320,6 +320,9 @@ sub finish {
         $thr->join;
     }
     sleep 1;
+    foreach my $p (0 .. $Threads) {
+        $framebuffer[$p]->cls();
+    }
     cls;
     exec('reset');
 } ## end sub finish
